@@ -1,7 +1,7 @@
 import express from 'express';
 import { simpleGet, simplePost, simplePut } from '@tamanu/shared/utils/crudHelpers';
 import asyncHandler from 'express-async-handler';
-import { REFERENCE_DATA_RELATION_TYPES, DEFAULT_HIERARCHY_TYPE } from '@tamanu/constants';
+import { REFERENCE_DATA_RELATION_TYPES, DEFAULT_HIERARCHY_TYPE, REFERENCE_TYPES } from '@tamanu/constants';
 import { NotFoundError } from '@tamanu/errors';
 import { keyBy, mapValues } from 'lodash';
 
@@ -17,11 +17,29 @@ referenceData.get(
       query: { leafNodeType, relationType = DEFAULT_HIERARCHY_TYPE },
     } = req;
 
-    const entity = await ReferenceData.getNode({
-      where: { type: leafNodeType },
-      raw: false,
-      relationType,
-    });
+    // Try to find a node for the requested leaf type; if not present, fall back to the
+    // deepest available configured type so incomplete hierarchies still render correctly.
+    const fallbackOrder = [
+      leafNodeType,
+      REFERENCE_TYPES.SETTLEMENT,
+      REFERENCE_TYPES.SUBDIVISION,
+      REFERENCE_TYPES.DIVISION,
+    ];
+
+    let entity = null;
+    for (const candidateType of fallbackOrder) {
+      if (!candidateType) continue;
+      const found = await ReferenceData.getNode({
+        where: { type: candidateType },
+        raw: false,
+        relationType,
+      });
+      if (found) {
+        entity = found;
+        break;
+      }
+    }
+
     if (!entity) {
       return res.send([]);
     }
@@ -30,7 +48,7 @@ referenceData.get(
     // in the hierarchy is fully connected to the next layer across all nodes. There for the list of ancestor
     // types is the total list of types in the hierarchy.
     const ancestors = await entity.getAncestors(relationType);
-    const hierarchyTypes = [...ancestors, entity.get({ plain: true })].map(e => e.type);
+    const hierarchyTypes = [...ancestors, entity.get({ plain: true })].map((e) => e.type);
     res.send(hierarchyTypes);
   }),
 );
